@@ -355,11 +355,12 @@ type MachineCheckStatus struct {
 }
 
 type MachinePort struct {
-	Port       *int     `json:"port,omitempty" toml:"port,omitempty"`
-	StartPort  *int     `json:"start_port,omitempty" toml:"start_port,omitempty"`
-	EndPort    *int     `json:"end_port,omitempty" toml:"end_port,omitempty"`
-	Handlers   []string `json:"handlers,omitempty" toml:"handlers,omitempty"`
-	ForceHttps bool     `json:"force_https,omitempty" toml:"force_https,omitempty"`
+	Port       *int        `json:"port,omitempty" toml:"port,omitempty"`
+	StartPort  *int        `json:"start_port,omitempty" toml:"start_port,omitempty"`
+	EndPort    *int        `json:"end_port,omitempty" toml:"end_port,omitempty"`
+	Handlers   []string    `json:"handlers,omitempty" toml:"handlers,omitempty"`
+	ForceHttps bool        `json:"force_https,omitempty" toml:"force_https,omitempty"`
+	TlsOptions *TlsOptions `json:"tls_options,omitempty" toml:"tls_options,omitempty"`
 }
 
 func (mp *MachinePort) ContainsPort(port int) bool {
@@ -410,9 +411,16 @@ func (mp *MachinePort) HasNonHttpPorts() bool {
 	return false
 }
 
+type TlsOptions struct {
+	Alpn     []string `json:"alpn,omitempty" toml:"alpn,omitempty"`
+	Versions []string `json:"versions,omitempty" toml:"version,omitempty"`
+}
+
 type MachineService struct {
 	Protocol     string                     `json:"protocol,omitempty" toml:"protocol,omitempty"`
 	InternalPort int                        `json:"internal_port,omitempty" toml:"internal_port,omitempty"`
+	Autostop     *bool                      `json:"autostop,omitempty"`
+	Autostart    *bool                      `json:"autostart,omitempty"`
 	Ports        []MachinePort              `json:"ports,omitempty" toml:"ports,omitempty"`
 	Checks       []MachineCheck             `json:"checks,omitempty" toml:"checks,omitempty"`
 	Concurrency  *MachineServiceConcurrency `json:"concurrency,omitempty" toml:"concurrency"`
@@ -424,11 +432,6 @@ type MachineServiceConcurrency struct {
 	SoftLimit int    `json:"soft_limit,omitempty" toml:"soft_limit,omitempty"`
 }
 
-type MachineFlyProxy struct {
-	AutostartMachine *bool `json:"autostart_machine,omitempty"`
-	AutostopMachine  *bool `json:"autostop_machine,omitempty"`
-}
-
 type MachineConfig struct {
 	// Fields managed from fly.toml
 	// If you add anything here, ensure appconfig.Config.ToMachine() is updated
@@ -451,12 +454,16 @@ type MachineConfig struct {
 	Restart     MachineRestart   `json:"restart,omitempty"`
 	Guest       *MachineGuest    `json:"guest,omitempty"`
 	DNS         *DNSConfig       `json:"dns,omitempty"`
-	FlyProxy    *MachineFlyProxy `json:"fly_proxy,omitempty"`
 	Processes   []MachineProcess `json:"processes,omitempty"`
 
+	// Not used by flyctl yet
+	// Standbys enable a machine to be a standby for another. In the event of a hardware failure,
+	// the standby machine will be started.
+	Standbys []string `json:"standbys,omitempty"`
+
 	// Deprecated: use Guest instead
 	VMSize string `json:"size,omitempty"`
-	// Deprecated: use FlyProxy.AutostartMachine instead
+	// Deprecated: use Service.Autostart instead
 	DisableMachineAutostart *bool `json:"disable_machine_autostart,omitempty"`
 }
 
