@@ -70,8 +70,8 @@ func TestFromDefinition(t *testing.T) {
 	assert.NoError(t, err)
 
 	assert.Equal(t, &Config{
-		KillSignal:  "SIGINT",
-		KillTimeout: 5,
+		KillSignal:  api.Pointer("SIGINT"),
+		KillTimeout: api.Pointer(5),
 		Experimental: &Experimental{
 			AutoRollback: true,
 		},
@@ -99,10 +99,10 @@ func TestFromDefinition(t *testing.T) {
 				Processes: []string{"app"},
 				TCPChecks: []*ServiceTCPCheck{
 					{
-						Timeout:      mustParseDuration("2s"),
+						Timeout:      api.MustParseDuration("2s"),
 						RestartLimit: 0,
-						Interval:     mustParseDuration("15s"),
-						GracePeriod:  mustParseDuration("1s"),
+						Interval:     api.MustParseDuration("15s"),
+						GracePeriod:  api.MustParseDuration("1s"),
 					},
 				},
 			},
@@ -220,10 +220,10 @@ func TestToDefinition(t *testing.T) {
 				"url_prefix": "/static-assets",
 			},
 		},
-		"mounts": map[string]any{
+		"mounts": []map[string]any{{
 			"source":      "data",
 			"destination": "/data",
-		},
+		}},
 		"processes": map[string]any{
 			"web":  "run web",
 			"task": "task all day",
