@@ -1,6 +1,8 @@
 package appconfig
 
 import (
+	"fmt"
+
 	"github.com/google/shlex"
 	"github.com/samber/lo"
 	"github.com/superfly/flyctl/api"
@@ -89,6 +91,15 @@ func (c *Config) updateMachineConfig(src *api.MachineConfig) (*api.MachineConfig
 			if err != nil {
 				return nil, err
 			}
+			if machineCheck.Port == nil {
+				if c.HTTPService == nil {
+					return nil, fmt.Errorf(
+						"Check '%s' for group '%s' has no internal port set and there is no http_service to refer to",
+						processGroup, checkName,
+					)
+				}
+				machineCheck.Port = &c.HTTPService.InternalPort
+			}
 			mConfig.Checks[checkName] = *machineCheck
 		}
 	}
@@ -110,11 +121,11 @@ func (c *Config) updateMachineConfig(src *api.MachineConfig) (*api.MachineConfig
 
 	// Mounts
 	mConfig.Mounts = nil
-	if c.Mounts != nil {
-		mConfig.Mounts = []api.MachineMount{{
-			Path: c.Mounts.Destination,
-			Name: c.Mounts.Source,
-		}}
+	for _, m := range c.Mounts {
+		mConfig.Mounts = append(mConfig.Mounts, api.MachineMount{
+			Path: m.Destination,
+			Name: m.Source,
+		})
 	}
 
 	return mConfig, nil
