@@ -54,11 +54,6 @@ func newMigrateToV2() *cobra.Command {
 		flag.Yes(),
 		flag.App(),
 		flag.AppConfig(),
-		flag.Bool{
-			// Note: This is referenced in a preflight test, make sure to remove that when removing this flag!
-			Name:        "experimental-volume-migration",
-			Description: "Migrate apps with volumes. Causes brief downtime. Experimental feature, use at your own risk!",
-		},
 		flag.String{
 			Name:        "primary-region",
 			Description: "Specify primary region if one is not set in fly.toml",
@@ -417,7 +412,7 @@ func (m *v2PlatformMigrator) Migrate(ctx context.Context) (err error) {
 		return abortedErr
 	}
 
-	if !m.isPostgres {
+	if !m.isPostgres && m.usesForkedVolumes {
 		tb.Detail("Making snapshots of volumes for the new machines")
 		err = m.migrateAppVolumes(ctx)
 		if err != nil {
